Structs
- Legacy
Node Info - Node legacy metadata about a server running in the federation, only used for deserialization.
- Node
Info Internal - Node metadata about a server running in the fediverse.
- Services
- Services tell about third party sites the node can connect to or interact with.
- Software
- Software contains infos about software running on the node.
- Usage
- Usage statistics for the node
- Users